@@ -17,8 +17,8 @@ package Dist::Zilla::PluginBundle::Author::CJM;
 # ABSTRACT: Build a distribution like CJM
 #---------------------------------------------------------------------
 
-our $VERSION = '4.13';
-# This file is part of Dist-Zilla-PluginBundle-Author-CJM 4.13 (March 21, 2012)
+our $VERSION = '4.20';
+# This file is part of Dist-Zilla-PluginBundle-Author-CJM 4.20 (August 24, 2013)
 
 use Moose;
 use Moose::Autobox;
@@ -71,12 +71,15 @@ sub configure
     [ GitVersionCheckCJM => scalar $self->config_slice({
         check_files => 'finder'
     }) ],
-    [ TemplateCJM => scalar $self->config_slice(
-        'changelog_re',
-        { pod_finder    => 'finder',
-          template_file => 'file',
-        },
-      ) ],
+    [ TemplateCJM => {
+        date_format => 'MMMM d, y',
+        %{$self->config_slice(
+          'changelog_re',
+          { pod_finder           => 'finder',
+            template_date_format => 'date_format',
+            template_file        => 'file',
+          })},
+      } ],
     [ Repository => { git_remote => 'github' } ],
   );
 
@@ -117,9 +120,9 @@ Dist::Zilla::PluginBundle::Author::CJM - Build a distribution like CJM
 
 =head1 VERSION
 
-This document describes version 4.13 of
-Dist::Zilla::PluginBundle::Author::CJM, released March 21, 2012
-as part of Dist-Zilla-PluginBundle-Author-CJM version 4.13.
+This document describes version 4.20 of
+Dist::Zilla::PluginBundle::Author::CJM, released August 24, 2013
+as part of Dist-Zilla-PluginBundle-Author-CJM version 4.20.
 
 =head1 SYNOPSIS
 
@@ -232,6 +235,11 @@ through L<@Filter|Dist::Zilla::PluginBundle::Filter>.
 Passed to CheckPrereqsIndexed as its C<skips>.
 
 
+=head2 template_date_format
+
+Passed to TemplateCJM as its C<date_format>.  Defaults to C<MMMM d, y>.
+
+
 =head2 template_file
 
 Passed to TemplateCJM as its C<file>.
@@ -266,7 +274,7 @@ L<< http://github.com/madsen/dist-zilla-pluginbundle-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Christopher J. Madsen.
+This software is copyright (c) 2013 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
